/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the examples of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQuick 1.0

import QtMobility.sensors 1.1

Rectangle {
    id: screen
    width: 150
    height: 150


    Rectangle {
        anchors.fill: parent
        opacity: hasAccelerometer ? 0.0 : 1.0
        z: 10
        Text {
            anchors.centerIn: parent
            text: "Accelerometer not found."
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: screen.start()
    }

    Accelerometer {
        id: sensor

        onReadingChanged: {
            xText.text = "X: " + reading.x.toFixed(2)
            yText.text = "Y: " + reading.y.toFixed(2)
            zText.text = "Z: " + reading.z.toFixed(2)

            var subFromAngle = screen.width > screen.height ? Math.PI : Math.PI/2
            var angle = Math.atan2(reading.y, -reading.x)
            theColumn.rotation = (angle-subFromAngle) * (180/Math.PI)

            if (Math.abs(reading.x) < 2.0 && Math.abs(reading.y) < 2.0) {
                inactiveTimer.start()
            } else {
                inactiveTimer.stop()
            }
        }
    }

    function stop()
    {
        if (sensor.active) {
            sensor.stop()
        }
    }

    function start()
    {
        if (!sensor.active) {
            sensor.start()
        }
    }

    Timer {
        id: inactiveTimer
        interval: 2000

        onTriggered: screen.stop()
    }

    Text {
        text: screen.width > screen.height ?
                  "Accelerometer Example" : "Accelerometer<br>Example"
        font.pointSize: 11
        horizontalAlignment: Text.AlignHCenter
        anchors {
            top: parent.top
            horizontalCenter: parent.horizontalCenter
        }
    }

    Text {
        text: "<center>Stopped. Click screen<br>to restart.</center>"
        font.pointSize: 11
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        opacity: sensor.active ? 0.0 : 1.0
    }

    Column {
        opacity: sensor.active ? 1.0 : 0.15
        anchors.centerIn: parent
        id: theColumn
        Text {
            id: xText
            font.pointSize: 15
        }
        Text {
            id: yText
            font.pointSize: 15
        }
        Text {
            id: zText
            font.pointSize: 15
        }
    }

    Component.onCompleted: {
        if (hasAccelerometer)
            screen.start()
    }
}

